Documentation
¶
Index ¶
Constants ¶
const OperationKeyValidation = "Validation"
OperationKeyValidation represents the key for the Operation field of an ValidationError
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Arguments ¶
type Arguments struct {
CPU bool `short:"c" long:"cpu" description:"Include the total CPU consumption"`
Mem bool `short:"m" long:"mem" description:"Include the total RAM consumption"`
Disk bool `short:"d" long:"disk" description:"Include the total CPU consumption"`
Processes bool `short:"p" long:"proc" description:"Include the top 10 processes"`
Health string `long:"health" description:"Make a healthcheck call against the URI"`
// contains filtered or unexported fields
}
Arguments represent the flags given at program start.
func (*Arguments) Validate ¶
func (a *Arguments) Validate() []ValidationError
Validate the arguments.
type ValidationError ¶
ValidationError is a struct to wrap the error with more information.
func (*ValidationError) Error ¶
func (ve *ValidationError) Error() string
Click to show internal directories.
Click to hide internal directories.